@@ -13,7 +13,7 @@ use IRC::Server::Tree;
 sub new {
   my $class = shift;
 
-  my $memoize;
+  my $memoize = 1;
   my $tree = sub {
 
     if (@_ == 1) {
@@ -156,7 +156,7 @@ sub split_peer {
     delete $self->{seen}->{$_} for @$names;
   }
 
-  wantarray ? @$names : $names
+  $names
 }
 
 sub trace {
@@ -171,10 +171,10 @@ sub trace {
   ##  (a search to get indexes, a walk to get names)
   ## If we memoize the route, we spend more memory on hop names.
   my $index_route = $self->tree->trace_indexes( $peer );
-  return unless ref $index_route eq 'ARRAY' and @$index_route;
+  return unless ref $index_route eq 'ARRAY' and scalar @$index_route;
 
   my $named_hops  = $self->tree->path_by_indexes( $index_route );
-  return unless ref $named_hops eq 'ARRAY' and @$named_hops;
+  return unless ref $named_hops eq 'ARRAY' and scalar @$named_hops;
 
   $self->{seen}->{$peer} = $index_route if $self->{memoize};
 
@@ -235,15 +235,15 @@ and uniqueness-checking.
     IRC::Server::Tree->new( $previous_tree )
   );
 
-The constructor initializes a fresh Network.
+The constructor initializes a new Network.
 
-=head3 memoize
+B<memoize>
 
 Setting 'memoize' to a false value at construction time will disable 
 route preservation, saving some memory at the expense of more frequent 
 tree searches.
 
-=head3 tree
+B<tree>
 
 If an existing Tree is passed in, a list of unique node names in the Tree 
 is compiled and validated.
@@ -291,7 +291,7 @@ than finding a path for each call.)
 
 =head2 hop_count
 
-  my $count = $net->hop_count;
+  my $count = $net->hop_count( $peer_name );
 
 Returns the number of hops to the destination node; i.e., a 
 directly-linked peer is 1 hop away:
@@ -301,6 +301,18 @@ directly-linked peer is 1 hop away:
     hubB      - 1 hop
       leafB   - 2 hops
 
+Returns empty list if the peer was not found.
+
+=head2 reset_tree
+
+  $net->reset_tree;
+
+Clears all currently-known routes and re-validates the tree.
+
+You shouldn't normally need to call this yourself unless you are in the 
+process of breaking things severely (such as manipulating the stored 
+L</tree>).
+
 =head2 split_peer
 
   my $split_names = $net->split_peer( $peer_name );
@@ -310,12 +322,19 @@ Splits a node from the tree.
 Returns an ARRAY containing the names of every node beneath the one that 
 was split, not including the originally specified peer.
 
+Returns empty list if the peer was not found.
+
+Returns empty arrayref if the node was split but no nodes were underneath 
+the split node.
+
 =head2 trace
 
   my $trace_names = $net->trace( $peer_name );
 
-Returns the same value as L<IRC::Server::Tree/trace>; see the 
-documentation for L<IRC::Server::Tree> for details.
+A successful trace returns the same value as L<IRC::Server::Tree/trace>; 
+see the documentation for L<IRC::Server::Tree> for details.
+
+Returns empty list if the peer was not found.
 
 This proxy method memoizes routes for future lookups. They are cleared 
 when L</split_peer> is called.
